```bash
docker build \
  -t us-docker.pkg.dev/cube-devrel-team/cube-twitter-stream/producer \
  --platform linux/amd64 .

docker push \
  us-docker.pkg.dev/cube-devrel-team/cube-twitter-stream/producer
```

```sql
CREATE OR REPLACE STREAM TWEETS_4 (
  ID STRING KEY,
  LANG STRING,
  PUBLIC_METRICS MAP<STRING, INT>,
  REPLY_SETTINGS STRING,
  SOURCE STRING,
  TEXT STRING,
  AUTHOR MAP<STRING, STRING>,
  ENTITIES MAP<STRING, ARRAY<MAP<STRING, STRING>>>,
  CREATED_AT STRING
) WITH (
  KAFKA_TOPIC='test_4',
  KEY_FORMAT='json',
  VALUE_FORMAT='json'
);

CREATE OR REPLACE TABLE STATS_4
AS SELECT
  ID,
  UNIX_TIMESTAMP(PARSE_TIMESTAMP(LATEST_BY_OFFSET(CREATED_AT), 'yyyy-MM-dd''T''HH:mm:ss.SSS''Z''')) AS CREATED_AT,
  COALESCE(LATEST_BY_OFFSET(LANG), 'UNDEFINED') AS LANGUAGE,
  COALESCE(LATEST_BY_OFFSET(PUBLIC_METRICS)['retweet_count'], 0) AS RETWEET_COUNT,
  COALESCE(LATEST_BY_OFFSET(PUBLIC_METRICS)['reply_count'], 0) AS REPLY_COUNT,
  COALESCE(LATEST_BY_OFFSET(PUBLIC_METRICS)['like_count'], 0) AS LIKE_COUNT,
  COALESCE(LATEST_BY_OFFSET(PUBLIC_METRICS)['quote_count'], 0) AS QUOTE_COUNT,
  COALESCE(LATEST_BY_OFFSET(REPLY_SETTINGS), 'UNDEFINED') AS REPLY_SETTINGS,
  COALESCE(LATEST_BY_OFFSET(SOURCE), 'UNDEFINED') AS SOURCE,
  LATEST_BY_OFFSET(TEXT) AS TEXT,
  LEN(LATEST_BY_OFFSET(TEXT)) AS TEXT_LENGTH,
  COALESCE(LATEST_BY_OFFSET(AUTHOR)['username'], 'UNDEFINED') AS AUTHOR_USERNAME,
  COALESCE(LATEST_BY_OFFSET(AUTHOR)['name'], 'UNDEFINED') AS AUTHOR_NAME,
  COALESCE(LATEST_BY_OFFSET(AUTHOR)['description'], 'UNDEFINED') AS AUTHOR_DESCRIPTION,
  COALESCE(LATEST_BY_OFFSET(AUTHOR)['location'], 'UNDEFINED') AS AUTHOR_LOCATION,
  COALESCE(LATEST_BY_OFFSET(AUTHOR)['verified'], 'UNDEFINED') AS AUTHOR_VERIFIED,
  COALESCE(ARRAY_LENGTH(LATEST_BY_OFFSET(ENTITIES)['mentions']), 0) AS MENTION_COUNT,
  COALESCE(ARRAY_LENGTH(LATEST_BY_OFFSET(ENTITIES)['hashtags']), 0) AS HASHTAG_COUNT,
  COALESCE(ARRAY_LENGTH(LATEST_BY_OFFSET(ENTITIES)['urls']), 0) AS URL_COUNT
FROM TWEETS_4
GROUP BY ID;

CREATE OR REPLACE STREAM HASHTAGS
AS SELECT
  ID,
  CONCAT(ID, '_', EXPLODE(ENTITIES['hashtags'])['start']) AS TAG_ID,
  EXPLODE(ENTITIES['hashtags'])['tag'] AS TAG
FROM TWEETS_4;

CREATE OR REPLACE STREAM MENTIONS
AS SELECT
  ID,
  CONCAT(ID, '_', EXPLODE(ENTITIES['mentions'])['id']) AS MENTION_ID,
  EXPLODE(ENTITIES['mentions'])['id'] AS USER_ID,
  EXPLODE(ENTITIES['mentions'])['username'] AS USERNAME
FROM TWEETS_4;

CREATE OR REPLACE STREAM WORDS
AS SELECT
  ID,
  CONCAT(ID, '_', EXPLODE(SPLIT(LCASE(REGEXP_REPLACE(TEXT, '\W', ' ')), ' '))) AS WORD_ID,
  EXPLODE(SPLIT(LCASE(REGEXP_REPLACE(TEXT, '\W', ' ')), ' ')) AS WORD,
  LEN(EXPLODE(SPLIT(LCASE(REGEXP_REPLACE(TEXT, '\W', ' ')), ' '))) AS WORD_LENGTH
FROM TWEETS_4;

SELECT * FROM stats;
```